// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import ProgressiveImage from 'react-progressive-image'

export const defaultStyles = {
  title: 'f3 f1-ns mw8 center lh-title fw9 tc',
  author: 'f5 f4-ns fw6 center',
  body: 'mw7 center mt3 mt4-ns pa3 pa3-ns',
}

const Article = ({
  post: {
    title,
    author,
    headerColor,
    overlayColor = 'rgba(0, 0, 0, 0)',
    image,
    smallImage,
    body,
  },
  theme,
}: {
  post: TPost,
  theme: { [key: string]: string },
}) => (
  <article data-component="Article">
    <header className={cn('relative w-100', headerColor, { 'vh-75': !!image })}>
      {/* Split into 2 components for easier apply effect to background image  */}
      <ProgressiveImage src={image} placeholder={smallImage}>
        {src => (
          <div
            style={!image ? {} : {
              background: `linear-gradient(${overlayColor}, ${overlayColor}), url(${src})`,
            }}
            className={cn('absolute aspect-ratio--object cover')}
          />
        )}
      </ProgressiveImage>
      <div className="absolute aspect-ratio--object v-mid ph3 ph4-m ph5-l flex flex-column justify-center">
        <h1 className={theme.title}>
          {title}
        </h1>
        <h2 className={theme.author}>
          {author}
        </h2>
      </div>
    </header>
    <div
      className={cn('markdown content', theme.body)}
      dangerouslySetInnerHTML={{ __html: body }}
    />
  </article>
)

export default themr('Article', {}, { composeTheme: 'softly' })(Article)
