// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import ProgressiveImage from 'react-progressive-image'
import BaseLink from 'components/Link'

export const defaultStyles = {
  root: '',
  imageWrapper: '',
  image: '',
  title: 'f3 tc ph2 mt3 fw7',
  link: '',
  description: 'tc ph2 mt2',
}

const Card = ({
  item: {
    title,
    image,
    to,
    smallImage,
    description,
    actions = [],
  },
  titleElement = 'h3',
  Link = BaseLink,
  theme,
}: {
  className?: string,
  item: Item,
  titleElement?: string,
  Link?: any,
  theme: { [key: string]: string},
}) => {
  const Title = titleElement
  return (
    <div data-component="Card" className={cn('flex flex-column items-center', theme.root)}>
      <div className={theme.imageWrapper}>
        <ProgressiveImage src={image} placeholder={smallImage}>
          {src => <img className={theme.image} src={src} alt={title} />}
        </ProgressiveImage>
      </div>
      <Title className={theme.title}>
        <Link className={theme.link} to={to}>
          {title}
        </Link>
      </Title>
      <hr className={cn('flex-none', theme.hr)} />
      <div className={theme.description}>{description}</div>
      <div className={theme.footer}>
        {actions.length > 0 && actions.map(action => (
          <Link
            className={theme.action}
            key={action.href}
            to={action.href}
          >
            {action.label}
          </Link>
        ))}
      </div>
    </div>
  )
}

Card.defaultProps = {
  className: null,
  actions: null,
  titleElement: 'h3',
  Link: BaseLink,
}

export default themr('Card', {}, { composeTheme: 'softly' })(Card)
