// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Icon from 'components/Icon'

export const defaultStyles = {
  root: '',
  image: '',
  name: '',
  from: '',
  content: '',
}

const CustomerReviewListItem = ({
  item: { icon, image, name, from, content },
  className,
  theme,
}: {
  item: TCustomerReview,
  className?: string,
  theme: { [key: string]: string },
}) => (
  <div
    data-component="CustomerReviewListItem"
    className={cn('flex items-center', theme.root, className)}
  >
    {icon && (
      <div className={theme.icon}>
        <Icon name={icon} />
      </div>
    )}
    <div className={theme.meta}>
      <div className={theme.imageWrapper}>
        <img className={theme.image} src={image} alt={name} />
      </div>
      <div className={theme.nameWrapper}>
        <div className={theme.name}>{name}</div>
        <div className={theme.from}>{from}</div>
      </div>
    </div>
    <div className={theme.content}>{content}</div>
  </div>
)

CustomerReviewListItem.defaultProps = {
  className: null,
}

export default themr('CustomerReviewListItem', {}, { composeTheme: 'softly' })(CustomerReviewListItem)
