// @flow

import React from 'react'
import { withReducer } from 'recompose'
import { Motion, spring, presets } from 'react-motion'
import Waypoint from 'react-waypoint'

const ON_ENTER = 'ON_ENTER'
const ON_LEAVE = 'ON_LEAVE'

function reducer(state = {}, action) {
  switch (action.type) {
    case ON_ENTER:
      return {
        ...state,
        [action.payload]: true,
      }
    case ON_LEAVE:
      return {
        ...state,
        [action.payload]: false,
      }
    default:
      return state
  }
}

class Example extends React.Component { // eslint-disable-line
  props: {
    state: {
      a: any,
    },
    dispatch: Function,
  }

  render() {
    const { state: { a }, dispatch } = this.props
    return (
      <div>
        <div className="vh-100" />
        <div className="vh-100" />
        <Waypoint
          key="a"
          onEnter={() => {
            dispatch({ type: ON_ENTER, payload: 'a' })
          }}
        >
          <div>
            <div className="f3">Our Services</div>
            <div className="flex">
              <div className="w-100 w-third-ns pa2 pa3-ns">
                <Motion
                  defaultStyle={{
                    opacity: 0,
                    translateY: 400,
                  }}
                  style={{
                    opacity: a ? spring(1, presets.noWobble) : spring(0),
                    translateY: a ? spring(0, presets.noWobble) : spring(400),
                  }}
                >
                  {({ opacity, translateY }) => (
                    <div
                      className="pa2 pa3-ns bg-yellow"
                      style={{
                        opacity,
                        transform: `translateY(${translateY}px)`,
                      }}
                    >
                      <div className="f4">Component Design</div>
                      <div className="f5">If you decide to use a custom component as a child, style and dimensions props will be passed into that component for you to use however you want. If you pass a regular React DOM element, Transition will take care of applying the values for you by cloning your element and passing it in.</div>
                    </div>
                  )}
                </Motion>
              </div>
              <div className="w-100 w-third-ns pa2 pa3-ns">
                <Motion
                  defaultStyle={{
                    opacity: 0,
                    translateY: 800,
                  }}
                  style={{
                    opacity: a ? spring(1, presets.noWobble) : spring(0),
                    translateY: a ? spring(0, presets.noWobble) : spring(800),
                  }}
                >
                  {({ opacity, translateY }) => (
                    <div
                      className="pa2 pa3-ns bg-yellow"
                      style={{
                        opacity,
                        transform: `translateY(${translateY}px)`,
                      }}
                    >
                      <div className="f4">Component Design</div>
                      <div className="f5">If you decide to use a custom component as a child, style and dimensions props will be passed into that component for you to use however you want. If you pass a regular React DOM element, Transition will take care of applying the values for you by cloning your element and passing it in.</div>
                    </div>
                  )}
                </Motion>
              </div>
              <div className="w-100 w-third-ns pa2 pa3-ns">
                <Motion
                  defaultStyle={{
                    opacity: 0,
                    translateY: 1200,
                  }}
                  style={{
                    opacity: a ? spring(1, presets.noWobble) : spring(0),
                    translateY: a ? spring(0, presets.noWobble) : spring(1200),
                  }}
                >
                  {({ opacity, translateY }) => (
                    <div
                      className="pa2 pa3-ns bg-yellow"
                      style={{
                        opacity,
                        transform: `translateY(${translateY}px)`,
                      }}
                    >
                      <div className="f4">Component Design</div>
                      <div className="f5">If you decide to use a custom component as a child, style and dimensions props will be passed into that component for you to use however you want. If you pass a regular React DOM element, Transition will take care of applying the values for you by cloning your element and passing it in.</div>
                    </div>
                  )}
                </Motion>
              </div>
            </div>
          </div>
        </Waypoint>
        <div className="vh-100" />
        <div className="vh-100" />
      </div>
    )
  }
}

export default withReducer('state', 'dispatch', reducer)(Example)
