// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'

export const defaultStyles = {
  root: 'aspect-ratio--3x4 aspect-ratio--4x3-m aspect-ratio--16x9-l',
  container: 'flex items-center justify-center',
}

const Hero = ({
  backgroundImage,
  overlayColor = 'rgba(0, 0, 0, 0)',
  children,
  videos = [],
  theme,
}: {
  backgroundImage?: string,
  overlayColor?: string,
  children?: any,
  videos?: Array<string>,
  theme: { [key: string]: string },
}) => {
  const style = backgroundImage ? {
    background: `linear-gradient(${overlayColor}, ${overlayColor}), url(${backgroundImage})`,
  } : {}
  return (
    <div
      data-component="Hero"
      className={cn('relative cover', theme.root)}
      style={style}
    >
      <div
        className={cn('absolute absolute--fill z-1', theme.container)}
      >
        {children}
      </div>
      {videos.length > 0 && (
        <video
          className="dn db-l absolute z-0 w-100"
          playsInline
          autoPlay
          muted
          loop
          poster={backgroundImage}
        >
          {videos.map(video => (
            <source key={video} src={video} type="video/mp4" />
          ))}
        </video>
      )}
    </div>
  )
}

Hero.defaultProps = {
  children: null,
  className: null,
  backgroundImage: null,
  overlayColor: 'rgba(0, 0, 0, 0)',
  videos: [],
}

export default themr('Hero', {}, { composeTheme: 'softly' })(Hero)
