// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import HorizontalItem from 'components/HorizontalItem'

export const defaultStyles = {
  root: '',
  itemWrapper: 'w-100 w-50-ns',
  itemRoot: '',
  imageWrapper: '',
  image: 'h2 w2 pa2',
  bodyWrapper: '',
  title: 'f5 fw6',
  description: 'f6',
  footer: '',
  actionWrapper: '',
  action: '',
}

const HorizontalList = ({
  data,
  className,
  theme,
  Link,
}: {
  data: Array<Item>,
  className?: string,
  theme: { [key: string]: string},
  Link: any,
}) => (
  <div className={cn(theme.root, className)}>
    {data.map(item => (
      <div key={item.title} className={theme.itemWrapper}>
        <HorizontalItem
          item={item}
          theme={{
            root: theme.itemRoot,
            imageWrapper: theme.imageWrapper,
            image: theme.image,
            bodyWrapper: theme.bodyWrapper,
            title: theme.title,
            description: theme.description,
            footer: theme.footer,
            actionWrapper: theme.actionWrapper,
            action: theme.action,
          }}
          Link={Link}
        />
      </div>
    ))}
  </div>
)

HorizontalList.defaultProps = {
  className: null,
}

export default themr('HorizontalList', {}, { composeTheme: 'softly' })(HorizontalList)
