/* eslint-disable react/no-array-index-key */

// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import Markdown from 'react-markdown'
import { withState } from 'recompose'
import Icon from 'components/Icon'
import cn from 'classnames'

const _Item = ({
  title,
  tooltip,
  item,
  isHover,
  hover,
  theme,
}: {
  title: string,
  tooltip?: string,
  item: {
    value: string,
    enable: boolean,
  },
  isHover: boolean,
  hover: (isHover: boolean) => void,
  theme: { [key: string]: string },
}) => (
  <div className={cn('relative', theme.item, { 'light-silver': item.enable === false })}>
    {item.enable && <Icon name="fa-check" className="mr2 green" />}
    {(item.enable === false) && <Icon name="fa-times" className="mr2 red" />}
    <span className="b">{item.value}</span> {title} <span
      className="dib"
      onMouseOver={() => hover(true)}
      onMouseLeave={() => hover(false)}
    >
      {!!tooltip && (
        <Icon name="fa-info-circle" className="pa1 silver pointer f6" />
      )}
      {isHover && (
        <div
          className="absolute bg-black-80 white br2 pv1 ph2 z-9999 left-0 f6"
          style={{ left: 0, right: 0 }}
        >
          <Markdown className="tooltip-markdown white-80" source={tooltip} />
        </div>
      )}
    </span>
  </div>
)

_Item.defaultProps = {
  tooltip: null,
}

const Item = withState('isHover', 'hover', false)(_Item)

const PricingCard = ({
  className,
  fields,
  item,
  theme = {},
  renderLink,
}: {
  className?: string,
  item: TPricingTableItem,
  fields: Array<{
    key: string,
    title: string,
    tooltip?: string,
  }>,
  theme: { [key: string]: string },
  renderLink?: (callToAction: LinkData) => any,
}) => {
  const finalTheme = Object.assign({}, theme, item.theme)
  return (
    <div className={cn(className, finalTheme.root)}>
      <div className={finalTheme.name}>{item.name}</div>
      <div className={finalTheme.price}>{item.price}</div>
      <div className={finalTheme.body}>
        {fields.map(({ key, title, tooltip }) => (
          <Item
            key={key}
            item={item.items[key]}
            title={title}
            tooltip={tooltip}
            theme={theme}
          />
        ))}
      </div>
      <div className={finalTheme.callToAction}>
        {!renderLink && (
          <span>{item.callToAction.label}</span>
        )}
        {!!renderLink && renderLink(item.callToAction)}
      </div>
    </div>
  )
}

PricingCard.defaultProps = {
  className: null,
  renderLink: null,
}

const PricingTable = ({
  className,
  data: { fields = [], data },
  theme = {},
  renderLink,
}: {
  data: TPricingTableData,
  renderLink?: (callToAction: LinkData) => any,
  className?: string,
  theme: { [key: string]: string },
}) => {
  const keys = Object.keys(data)
  const itemTheme = {
    root: theme.itemRoot,
    name: theme.name,
    price: theme.price,
    body: theme.body,
    item: theme.item,
    callToAction: theme.callToAction,
  }

  return (
    <div className={cn(className, theme.root)}>
      <div className="flex flex-wrap">
        {keys.map(key => (
          <div key={key} className={theme.itemWrapper}>
            <PricingCard
              theme={itemTheme}
              fields={fields}
              item={data[key]}
              renderLink={renderLink}
            />
          </div>
        ))}
      </div>
    </div>
  )
}

PricingTable.defaultProps = {
  className: null,
  renderLink: null,
}

export default themr('PricingTable', {}, { composeTheme: 'softly' })(PricingTable)
