// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import qs from 'querystring'
import cn from 'classnames'
import Icon from 'components/Icon'

export const defaultStyles = {
  link: 'black-60 hover-black-80',
  icon: '',
}

const SocialShare = ({
  theme,
  url,
  text,
  email = true,
  useColor = true,
  facebook = true,
  googlePlus = true,
  linkedIn = false,
  pinterest = true,
  reddit = false,
  tumblr = true,
  twitter = true,
  whatsApp = true,
  xing = true,
}: {
  theme: { [key: string]: string },
  url: string,
  text?: string,
  useColor?: boolean,
  email?: boolean,
  facebook?: boolean,
  googlePlus?: boolean,
  linkedIn?: boolean,
  pinterest?: boolean,
  reddit?: boolean,
  tumblr?: boolean,
  twitter?: boolean,
  whatsApp?: boolean,
  xing?: boolean,
}) => (
  <div className={theme.root}>
    {email &&
    <a
      className={cn(theme.link, { _email: useColor })}
      href={`mailto:?${qs.stringify({ subject: text, body: url })}`}
      target="_self"
      aria-label="Share by E-Mail"
    >
      <Icon name="fa-envelope" className={theme.icon} />
    </a>}
    {facebook &&
    <a
      className={cn(theme.link, { _facebook: useColor })}
      href={`https://facebook.com/sharer/sharer.php?u=${url}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Facebook"
    >
      <Icon name="fa-facebook-square" className={theme.icon} />
    </a>}
    {googlePlus &&
    <a
      className={cn(theme.link, { _google: useColor })}
      href={`https://plus.google.com/share?url=${url}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Google+"
    >
      <Icon name="fa-google-plus-square" className={theme.icon} />
    </a>}
    {linkedIn &&
    <a
      className={cn(theme.link, { _linkedin: useColor })}
      href={`https://www.linkedin.com/shareArticle?${qs.stringify({
        mini: true,
        url,
        source: url,
        title: text,
        summary: text,
      })}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on LinkedIn"
    >
      <Icon name="fa-linkedin-square" className={theme.icon} />
    </a>}
    {pinterest &&
    <a
      className={cn(theme.link, { _pinterest: useColor })}
      href={`https://pinterest.com/pin/create/button/?${qs.stringify({
        url,
        media: url,
        summary: text,
      })}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Pinterest"
    >
      <Icon name="fa-pinterest-square" className={theme.icon} />
    </a>}
    {reddit &&
    <a
      className={cn(theme.link, { _reddit: useColor })}
      href={`https://reddit.com/submit/?url=${url}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Reddit"
    >
      <Icon name="fa-reddit-square" className={theme.icon} />
    </a>}
    {tumblr &&
    <a
      className={cn(theme.link, { _tumblr: useColor })}
      href={`https://www.tumblr.com/widgets/share/tool?${qs.stringify({
        posttype: 'link',
        title: text,
        caption: text,
        content: url,
        canonicalUrl: url,
        shareSource: 'tumblr_share_button',
      })}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Tumblr"
    >
      <Icon name="fa-tumblr-square" className={theme.icon} />
    </a>}
    {twitter &&
    <a
      className={cn(theme.link, { _twitter: useColor })}
      href={`https://twitter.com/intent/tweet/?&${qs.stringify({
        text,
        url,
      })}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on Twitter"
    >
      <Icon name="fa-twitter-square" className={theme.icon} />
    </a>}
    {whatsApp &&
    <a
      className={cn(theme.link, { _whatsapp: useColor })}
      href={`whatsapp://send?text=${text ? `${text} ` : ''}${url}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on WhatsApp"
    >
      <Icon name="fa-whatsapp" className={theme.icon} />
    </a>}
    {xing &&
    <a
      className={cn(theme.link, { _xing: useColor })}
      href={`https://www.xing.com/app/user?${qs.stringify({
        op: 'share',
        url,
        title: text,
      })}`}
      target="_blank"
      rel="noopener noreferrer"
      aria-label="Share on XING"
    >
      <Icon name="fa-xing-square" className={theme.icon} />
    </a>}
  </div>
  )

SocialShare.defaultProps = {
  text: 'string',
  useColor: false,
  email: true,
  facebook: true,
  googlePlus: true,
  linkedIn: false,
  pinterest: false,
  reddit: false,
  tumblr: false,
  twitter: false,
  whatsApp: false,
  xing: false,
}

export default themr('SocialShare', {}, { composeTheme: 'softly' })(SocialShare)
