'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaultStyles = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactCssThemr = require('react-css-themr');

var _reactForm = require('react-form');

var _TextInput = require('../TextInput');

var _TextInput2 = _interopRequireDefault(_TextInput);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaultStyles = exports.defaultStyles = {
  label: '',
  input: '',
  button: ''
};

var ContactForm = function ContactForm(_ref) {
  var className = _ref.className,
      nameLabel = _ref.nameLabel,
      emailLabel = _ref.emailLabel,
      phoneLabel = _ref.phoneLabel,
      descriptionLabel = _ref.descriptionLabel,
      submitLabel = _ref.submitLabel,
      onSubmit = _ref.onSubmit,
      _onValidationFail = _ref.onValidationFail,
      theme = _ref.theme;

  var inputTheme = {
    root: theme.inputWrapper,
    icon: theme.icon,
    input: theme.input
  };

  return _react2.default.createElement(
    _reactForm.Form,
    {
      'data-component': 'ContactForm',
      className: className,
      onSubmit: onSubmit,
      onValidationFail: function onValidationFail() {
        return _onValidationFail && _onValidationFail.apply(undefined, arguments);
      },
      validate: function validate(values) {
        var errors = {
          email: !values.email ? 'Email is required' : undefined,
          phone: !values.phone ? 'Phone is required' : undefined,
          name: !values.name ? 'Name is required' : undefined
        };
        return errors;
      }
    },
    function (_ref2) {
      var submitForm = _ref2.submitForm,
          getError = _ref2.getError;
      return _react2.default.createElement(
        'div',
        null,
        _react2.default.createElement(
          'form',
          {
            className: theme.form,
            onSubmit: submitForm
          },
          _react2.default.createElement(_TextInput2.default, {
            icon: 'fa-user',
            type: 'text',
            field: 'name',
            className: 'flex-auto w-100',
            placeholder: nameLabel,
            theme: inputTheme
          }),
          _react2.default.createElement(_TextInput2.default, {
            icon: 'fa-envelope-o',
            type: 'email',
            field: 'email',
            className: 'flex-auto w-100',
            placeholder: emailLabel,
            theme: inputTheme
          }),
          _react2.default.createElement(_TextInput2.default, {
            icon: 'fa-phone',
            field: 'phone',
            className: 'flex-auto w-100',
            placeholder: phoneLabel,
            theme: inputTheme
          }),
          _react2.default.createElement(_TextInput2.default, {
            icon: 'fa-pencil-square-o',
            field: 'description',
            multiline: true,
            rows: 5,
            className: 'flex-auto w-100',
            placeholder: descriptionLabel,
            theme: inputTheme
          }),
          _react2.default.createElement(
            'button',
            { className: theme.callToAction, type: 'submit' },
            submitLabel
          )
        ),
        _react2.default.createElement(
          'div',
          { className: theme.errorWrapper },
          ['name', 'email', 'phone', 'description'].map(function (item) {
            return _react2.default.createElement(
              'div',
              {
                key: item,
                className: theme.error
              },
              getError(item)
            );
          })
        )
      );
    }
  );
};

ContactForm.defaultProps = {
  children: null,
  className: null,
  nameLabel: 'Name',
  emailLabel: 'Email',
  phoneLabel: 'Phone',
  descriptionLabel: 'Description',
  submitLabel: 'Submit',
  onValidationFail: null
};

exports.default = (0, _reactCssThemr.themr)('ContactForm', {}, { composeTheme: 'softly' })(ContactForm);